==> effect_edc-0.1.12-py3-none-any.whl: effect_subject/admin/patient_history_admin.py <==
from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple

from ..admin_site import effect_subject_admin
from ..forms import PatientHistoryForm
from ..models import PatientHistory
from .modeladmin import CrfModelAdmin


@admin.register(PatientHistory, site=effect_subject_admin)
class PatientHistoryAdmin(CrfModelAdmin):

    form = PatientHistoryForm

    fieldsets = (
        (None, {"fields": ("subject_visit", "report_datetime")}),
        (
            "Previous treatment",
            {
                "description": "Only complete at Day 1",
                "fields": (
                    "flucon_1w_prior_rando",
                    "flucon_days",
                    "flucon_dose",
                    "flucon_dose_other",
                    "flucon_dose_other_reason",
                ),
            },
        ),
        (
            "Neurological",
            {"fields": ("reported_neuro_abnormality", "neuro_abnormality_details")},
        ),
        (
            "TB diagnosis/treatment",
            {
                "fields": (
                    "tb_prev_dx",
                    "tb_site",
                    "on_tb_tx",
                    "tb_dx_ago",
                    "on_rifampicin",
                    "rifampicin_start_date",
                )
            },
        ),
        (
            "Other opportunistic infections",
            {"fields": ("previous_oi", "previous_oi_name", "previous_oi_dx_date")},
        ),
        (
            "Other medication",
            {
                "fields": (
                    "any_medications",
                    "specify_medications",
                    "specify_steroid_other",
                    "specify_medications_other",
                ),
            },
        ),
        audit_fieldset_tuple,
    )

    filter_horizontal = ["specify_medications"]

    radio_fields = {
        "any_medications": admin.VERTICAL,
        "flucon_1w_prior_rando": admin.VERTICAL,
        "flucon_dose": admin.VERTICAL,
        "on_rifampicin": admin.VERTICAL,
        "on_tb_tx": admin.VERTICAL,
        "previous_oi": admin.VERTICAL,
        "reported_neuro_abnormality": admin.VERTICAL,
        "tb_dx_ago": admin.VERTICAL,
        "tb_prev_dx": admin.VERTICAL,
        "tb_site": admin.VERTICAL,
    }

==> effect_edc-0.1.19-py3-none-any.whl: effect_subject/admin/patient_history_admin.py <==
from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple

from ..admin_site import effect_subject_admin
from ..forms import PatientHistoryForm
from ..models import PatientHistory
from .modeladmin import CrfModelAdmin


@admin.register(PatientHistory, site=effect_subject_admin)
class PatientHistoryAdmin(CrfModelAdmin):

    form = PatientHistoryForm

    fieldsets = (
        (None, {"fields": ("subject_visit", "report_datetime")}),
        (
            "Fluconazole",
            {
                "description": "Only complete at Day 1",
                "fields": (
                    "flucon_1w_prior_rando",
                    "flucon_days",
                    "flucon_dose",
                    "flucon_dose_other",
                    "flucon_dose_other_reason",
                ),
            },
        ),
        (
            "Neurological",
            {"fields": ("reported_neuro_abnormality", "neuro_abnormality_details")},
        ),
        (
            "TB diagnosis",
            {
                "fields": (
                    "tb_prev_dx",
                    "tb_dx_date",
                    "tb_dx_date_estimated",
                    "tb_site",
                )
            },
        ),
        (
            "TB prevention/treatment",
            {
                "fields": (
                    "on_tb_tx",
                    "tb_tx_type",
                    "active_tb_tx",
                )
            },
        ),
        (
            "Other opportunistic infections",
            {"fields": ("previous_oi", "previous_oi_name", "previous_oi_dx_date")},
        ),
        (
            "Other medication",
            {
                "fields": (
                    "any_medications",
                    "specify_medications",
                    "specify_steroid_other",
                    "specify_medications_other",
                ),
            },
        ),
        audit_fieldset_tuple,
    )

    filter_horizontal = ["active_tb_tx", "specify_medications"]

    radio_fields = {
        "any_medications": admin.VERTICAL,
        "flucon_1w_prior_rando": admin.VERTICAL,
        "flucon_dose": admin.VERTICAL,
        "on_tb_tx": admin.VERTICAL,
        "previous_oi": admin.VERTICAL,
        "reported_neuro_abnormality": admin.VERTICAL,
        "tb_dx_date_estimated": admin.VERTICAL,
        "tb_prev_dx": admin.VERTICAL,
        "tb_site": admin.VERTICAL,
        "tb_tx_type": admin.VERTICAL,
    }
